##  Configuring KPIs
Admins can create custom KPIs and modify predefined ones in the KPIs section of the administration area. For details, see [Configuring KPIs](https://help.sap.com/docs/leanix/ea/configuring-kpis?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to configure KPIs and explore the concepts behind each configuration setting.").
